==> openshift-model-console-4.11.1-sources.jar: annotations/io/fabric8/openshift/api/model/console/v1/ConsoleYAMLSampleListFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ConsoleYAMLSampleListFluent<A extends ConsoleYAMLSampleListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ConsoleYAMLSample item);
    public A setToItems(int index,ConsoleYAMLSample item);
    public A addToItems(ConsoleYAMLSample... items);
    public A addAllToItems(Collection<ConsoleYAMLSample> items);
    public A removeFromItems(ConsoleYAMLSample... items);
    public A removeAllFromItems(Collection<ConsoleYAMLSample> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<ConsoleYAMLSampleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ConsoleYAMLSample> getItems();
    public List<ConsoleYAMLSample> buildItems();
    public ConsoleYAMLSample buildItem(int index);
    public ConsoleYAMLSample buildFirstItem();
    public ConsoleYAMLSample buildLastItem();
    public ConsoleYAMLSample buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ConsoleYAMLSampleBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ConsoleYAMLSampleBuilder> predicate);
    public A withItems(List<ConsoleYAMLSample> items);
    public A withItems(ConsoleYAMLSample... items);
    public Boolean hasItems();
    public ConsoleYAMLSampleListFluent.ItemsNested<A> addNewItem();
    public ConsoleYAMLSampleListFluent.ItemsNested<A> addNewItemLike(ConsoleYAMLSample item);
    public ConsoleYAMLSampleListFluent.ItemsNested<A> setNewItemLike(int index,ConsoleYAMLSample item);
    public ConsoleYAMLSampleListFluent.ItemsNested<A> editItem(int index);
    public ConsoleYAMLSampleListFluent.ItemsNested<A> editFirstItem();
    public ConsoleYAMLSampleListFluent.ItemsNested<A> editLastItem();
    public ConsoleYAMLSampleListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ConsoleYAMLSampleBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConsoleYAMLSampleFluent<ConsoleYAMLSampleListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> openshift-model-console-5.1.1-sources.jar: annotations/io/fabric8/openshift/api/model/console/v1/ConsoleYAMLSampleListFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ConsoleYAMLSampleListFluent<A extends ConsoleYAMLSampleListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ConsoleYAMLSample item);
    public A setToItems(int index,ConsoleYAMLSample item);
    public A addToItems(ConsoleYAMLSample... items);
    public A addAllToItems(Collection<ConsoleYAMLSample> items);
    public A removeFromItems(ConsoleYAMLSample... items);
    public A removeAllFromItems(Collection<ConsoleYAMLSample> items);
    public A removeMatchingFromItems(Predicate<ConsoleYAMLSampleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ConsoleYAMLSample> getItems();
    public List<ConsoleYAMLSample> buildItems();
    public ConsoleYAMLSample buildItem(int index);
    public ConsoleYAMLSample buildFirstItem();
    public ConsoleYAMLSample buildLastItem();
    public ConsoleYAMLSample buildMatchingItem(Predicate<ConsoleYAMLSampleBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<ConsoleYAMLSampleBuilder> predicate);
    public A withItems(List<ConsoleYAMLSample> items);
    public A withItems(ConsoleYAMLSample... items);
    public Boolean hasItems();
    public ConsoleYAMLSampleListFluent.ItemsNested<A> addNewItem();
    public ConsoleYAMLSampleListFluent.ItemsNested<A> addNewItemLike(ConsoleYAMLSample item);
    public ConsoleYAMLSampleListFluent.ItemsNested<A> setNewItemLike(int index,ConsoleYAMLSample item);
    public ConsoleYAMLSampleListFluent.ItemsNested<A> editItem(int index);
    public ConsoleYAMLSampleListFluent.ItemsNested<A> editFirstItem();
    public ConsoleYAMLSampleListFluent.ItemsNested<A> editLastItem();
    public ConsoleYAMLSampleListFluent.ItemsNested<A> editMatchingItem(Predicate<ConsoleYAMLSampleBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConsoleYAMLSampleFluent<ConsoleYAMLSampleListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
